@@ -166,12 +166,15 @@ def hall_conductivity(h,dk=-1,n=1000):
 
 
 
-def mesh_chern(h,dk=-1,nk=10,delta=0.0001,mode="Wilson",operator=None):
+def mesh_chern(h,dk=-1,nk=10,delta=0.0001,mode="Wilson",
+        operator=None,kmesh=None):
   """ Calculates the chern number of a 2d system """
   c = 0.0
   ks = [] # array for kpoints
   bs = [] # array for berrys
   if dk<0: dk = 1./float(2*nk) # automatic dk
+  if kmesh is not None: # infer the dk of the mesh
+      dk = klist.infer_kmesh_dk(kmesh,d=2)
   if operator is not None and mode=="Wilson":
     print("Switching to Green mode in topology")
     mode="Green"
@@ -183,17 +186,11 @@ def mesh_chern(h,dk=-1,nk=10,delta=0.0001,mode="Wilson",operator=None):
        f2 = h.get_gk_gen(delta=delta) # get generator
        return berry_green(f2,k=[k[0],k[1],0.],operator=operator) 
   ##################
-  for x in np.linspace(0.,1.,nk,endpoint=False):
-    for y in np.linspace(0.,1.,nk,endpoint=False):
-      ks.append([x,y]) # create kpoints
-#  tr = timing.Testimator("CHERN NUMBER")
+  if kmesh is None: # no kmesh provided
+      ks = klist.kmesh(h.dimensionality,nk=nk) # get the mesh
+  else: ks = kmesh # use the provided kmesh
   ik = 0
   bs = parallel.pcall(fberry,ks) # compute all the Berry curvatures
-#  for k in ks: # loop
-#    tr.remaining(ik,len(ks))
-#    ik += 1 # increase
-#    b = fberry(k) # get berry curvature
-#    bs.append(b)
   # write in file
   fo = open("BERRY_CURVATURE.OUT","w") # open file
   for (k,b) in zip(ks,bs):
@@ -203,7 +200,11 @@ def mesh_chern(h,dk=-1,nk=10,delta=0.0001,mode="Wilson",operator=None):
   fo.close() # close file
   ################
   c = np.sum(bs) # sum berry curvatures
-  c = c/(2.*np.pi*nk*nk)
+  if kmesh is None: # no kmesh provided
+      c = c/(2.*np.pi*nk*nk) # normalize
+  else: # kmesh is given
+      den = klist.infer_kmesh_density(kmesh,d=2) # infer the volume
+      c = den*c/(2.*np.pi) # normalize
   open("CHERN.OUT","w").write(str(c)+"\n")
   return c
 
@@ -472,70 +473,11 @@ def precise_spin_chern(h,delta=0.00001,tol=0.1):
   return c[0]/(2.*np.pi)
 
 
+from .topologytk.green import berry_green_generator
+from .topologytk.green import berry_green
+from .topologytk.green import berry_operator
 
 
-def berry_green_generator(f,k=[0.,0.,0.],dk=0.05,operator=None,
-              full=False):
-  """Function that returns the energy resolved Berry curvature"""
-  k = np.array(k) # set as array
-  dx = np.array([dk,0.,0.])
-  dy = np.array([0.,dk,0.])
-  def fint(e): # function to integrate
-#    g = f(e=e,k=k) # compute at this k and this energy
-    gxp = f(e=e,k=k+dx) # compute at this k and this energy
-    gxm = f(e=e,k=k-dx) # compute at this k and this energy
-    gyp = f(e=e,k=k+dy) # compute at this k and this energy
-    gym = f(e=e,k=k-dy) # compute at this k and this energy
-    g = (gxp + gyp + gxm + gym)/4. # average Green function
-    # Now apply the formula
-    gI = algebra.inv(g) # inverse
-    # the derivative of g^-1 is -g^-1*g'*g^-1
-    omega = -(gxp-gxm)@gI@(gyp-gym) + (gyp-gym)@gI@(gxp-gxm)
-#    omega = ((gxp-gxm)@(gyp-gym) - (gyp-gym)@(gxp-gxm))@gI
-#    omega = g*((gxp.I-gxm.I)*(gyp-gym) -(gyp.I-gym.I)*(gxp-gxm))
-#    omega += -g*(gyp.I-gym.I)*(gxp-gxm)
-    if operator is not None: omega = operator(omega,k=k) 
-    if full: return omega/(4.*dk*dk*2.*np.pi) # return the full matrix
-    else: return np.trace(omega)/(4.*dk*dk*2.*np.pi) # return contribution
-  return fint # return the function
-
-
-
-
-def berry_green(f,emin=-10.0,k=[0.,0.,0.],ne=100,dk=0.0001,operator=None):
-  """Return the Berry curvature using Green functions"""
-  import scipy.integrate as integrate
-  fint = berry_green_generator(f,k=k,dk=dk,operator=operator) 
-  es = np.linspace(emin,0.,ne) # energies used for the integration
-  ### The original function is defined in the coplex plane,
-  # we will do a change of variables of the form z = re^(iphi) - r0
-  # so that dz = re^(iphi) i dphi
-  def fint2(x):
-    """Function to integrate using a complex contour, from 0 to 1"""
-    z0 = emin*np.exp(-1j*x*np.pi)/2.
-    z = z0 + emin/2.
-    return -(fint(z)*z0).imag*np.pi # integral after the change of variables
-  return integrate.quad(fint2,0.0,1.0,limit=60,epsabs=0.1,epsrel=0.1)[0]
-#  return integrate.quad(fint,emin,0.0,limit=60,epsabs=0.01,epsrel=0.01)[0]
-#  return np.sum([fint(e) for e in es]) # return
-
-
-def berry_operator(h,delta=1e-1,**kwargs):
-    """Return ap operator that computes the Berry curvature for a certain
-    wavefunction"""
-    if h.dimensionality!=2: raise
-    h = h.copy()
-    h.turn_dense()
-    hk = h.get_hk_gen() # get generator
-    gk = h.get_gk_gen(delta=delta) # get generator
-    def bk(k): return berry_green_generator(gk,k=k,**kwargs) 
-    def outf(w,k=[0.,0.,0.]):
-        m = hk(k) # bloch Hamiltonian
-        e = algebra.braket_wAw(w,m) # energy
-        o = bk(k)(e)*delta # Berry curvature
-        return o*w # return a vector
-    return outf
-
 
 def berry_green_map_kpoint(h,emin=None,k=[0.,0.,0.],
         ne=100,dk=0.0001,operator=None,integral_mode="complex",
